complete -c wpaperd -s c -l config -d 'Path to the configuration (XDG_CONFIG_HOME/wpaperd/config.toml by default)' -r -F
complete -c wpaperd -l notify -d 'Readiness fd used by wpaperd to signal that it has started correctly' -r
complete -c wpaperd -s d -l daemon -d 'Detach from the current terminal and run in the background'
complete -c wpaperd -s v -l verbose -d 'Increase the verbosity of wpaperd'
complete -c wpaperd -s h -l help -d 'Print help'
complete -c wpaperd -s V -l version -d 'Print version'
